############ Pseudo-t vs. Spretus divergence ###############
############################################################

########### Choose base path ################
#base_path <- "/home/rkelemen/Seafile/Work/Work/T-hap-Paper-Revisions/"
base_path <- "/Users/rkelemen/Seafile/Work/T-hap-Paper-Revisions/"
############################################

########### Choose dataset ################
folder <- "Data/Divergence/PASS_SNPs/Controls/PseudoTvsSpretus/"
fileSave <- "DataToPlot/PASS_SNPs/rollmeanTDivRollmeanNonT_PseudoVsSpretusDivergenceFigure"

folder <- "Data/Divergence/PASS_SNPs/Controls/PseudoTvsSpretusNeutral/"
fileSave <- "DataToPlot/PASS_SNPs/rollmeanTDivRollmeanNonT_PseudoVsSpretusNeutralDivergenceFigure"

folder <- "Data/Divergence/raw_SNPs/Controls/PseudoTvsSpretus/"
fileSave <- "DataToPlot/raw_SNPs/rollmeanTDivRollmeanNonT_PseudoVsSpretusDivergenceFigure"

folder <- "Data/Divergence/raw_SNPs/Controls/PseudoTvsSpretusNeutral/"
fileSave <- "DataToPlot/raw_SNPs/rollmeanTDivRollmeanNonT_PseudoVsSpretusNeutralDivergenceFigure"
############################################

path <- paste(base_path,folder,sep = "")

files <- list.files(path) ### list files in directory of interest
t.files <- 1:4  ### file index of pseudo-ts
nont.files <- setdiff((1:length(files)),t.files) ## file index of spretus

binSize <- 1000 # number of basepairs in bin
k.val <- 10^6/binSize # number of bins to take in a window of rollmean(), to end up with a rollmean window of 1 Mb

########## Spretus - compute average SNP density per Kb ####################
############################################################################

density.wt.average <- rep(0,95000000/binSize)
for(i in nont.files){
  coors <- as.numeric(unlist(read.table(paste(path,files[i],sep = "")))) ### read in coordinates of snps for individual
  h <- hist((coors/binSize), breaks = seq(0,95000000/binSize,1), plot=F) #count in bins 
  density.wt.average <- density.wt.average + h$counts
}
d.mids <- h$mids
density.wt.average <- density.wt.average/length(nont.files)

########## t-carriers - compute average SNP density per Kb #############
########################################################################

density.t.average <- rep(0,95000000/binSize)
for(i in t.files){
  coors <- as.numeric(unlist(read.table(paste(path,files[i],sep = "")))) ### read in coordinates of snps for individual
  h <- hist((coors/binSize), breaks = seq(0,95000000/binSize,1), plot=F) #count in bins
  density.t.average <- density.t.average + h$counts
}
density.t.average <- density.t.average/length(t.files)

density.t.average <- c()
for(i in t.files){
  coors <- as.numeric(unlist(read.table(paste(path,files[i],sep = "")))) ### read in coordinates of snps for individual
  h <- hist((coors/binSize), breaks = seq(0,95000000/binSize,1), plot=F) #count in bins
  density.t.average <- cbind(density.t.average,h$counts)
}
rm.x <- rollmean(h$mids,k = k.val)
rm.y1 <- rollmean(density.t.average[,1],k = k.val)
rm.y2 <- rollmean(density.t.average[,2],k = k.val)
rm.y3 <- rollmean(density.t.average[,3],k = k.val)
rm.y4 <- rollmean(density.t.average[,4],k = k.val)

par(mfrow=c(1,1))
plot(rm.x,rm.y1, ylim=c(0,12), type = "l", lwd=3, frame.plot = F, xlab="Chr17 Position",ylab = "Pseudo-t SNP density / Mb")
par(new=T)
plot(rm.x,rm.y2,col="blue", ylim=c(0,12), type = "l", lwd=3, frame.plot = F, axes=F,xlab="",ylab = "")
par(new=T)
plot(rm.x,rm.y3,col="red", ylim=c(0,12), type = "l", lwd=3, frame.plot = F, axes=F,xlab="",ylab = "")
par(new=T)
plot(rm.x,rm.y4,col="green", ylim=c(0,12), type = "l", lwd=3, frame.plot = F, axes=F,xlab="",ylab = "")

######## Compute rolling mean of t/wt heterozygosity #############
##################################################################
#install.packages("zoo")
library(zoo)
rm.x <- rollmean(d.mids,k = k.val)
rm.y1 <- rollmean(density.t.average,k = k.val)
rm.y2 <- rollmean(density.wt.average,k = k.val)
toPlot <- cbind(rm.x,rm.y1/rm.y2)

pathToSaveTo <- paste(base_path,fileSave,sep = "")
save(toPlot,file = pathToSaveTo)
load(pathToSaveTo)


par(mfrow=c(1,1),mar=rep(4,4))
plot(toPlot[,1],toPlot[,2],type = "l",axes=F,lwd=3, xlab="", ylab = "")
axis(1,at = seq(5000000/binSize,95000000/binSize,5000000/binSize), labels = seq(5,95,5))
axis(2)
title(ylab = "Excess neutral divergence of the t-haplotype compared to Spretus")
title(xlab = "Position on Chr17 (Mb)")

##
plot(rm.x,rm.y1,type="l")
plot(rm.x,rm.y2,type="l")
