#These are the R commands for running Sleuth
library("sleuth")

#set directory of Kallisto Results
base_dir <- "/nfs/scistore03/vicosgrp/bvicoso/Reka/ThapGenetics/Expression/Kallisto_output"
sample_id <- dir(file.path(base_dir, "ERP013320_Liver"))
kal_dirs <- sapply(sample_id, function(id) file.path(base_dir, "ERP013320_Liver", id))

#give sample information
s2c <- read.table(file.path(base_dir, "Liver_sampleinfo.txt"), header = TRUE, stringsAsFactors=FALSE)
s2c <- dplyr::select(s2c, sample = sample, condition)
s2c
s2c <- dplyr::mutate(s2c, path = kal_dirs)
s2c

#run Sleuth
mart <- biomaRt::useMart(biomart = "ENSEMBL_MART_ENSEMBL", dataset="mmusculus_gene_ensembl", host = 'ensembl.org')
t2g <- biomaRt::getBM(attributes = c("ensembl_transcript_id", "ensembl_gene_id", "external_gene_name"), mart = mart)
t2g <- dplyr::rename(t2g, target_id = ensembl_transcript_id, ens_gene = ensembl_gene_id, ext_gene = external_gene_name)
so <- sleuth_prep(s2c, ~condition, target_mapping = t2g, aggregation_column = 'ens_gene')
so <- sleuth_fit(so)
so <- sleuth_fit(so, ~1, 'reduced')
so <- sleuth_lrt(so, 'reduced', 'full')

#Get Results!
results_table <- sleuth_results(so, 'reduced:full', test_type = 'lrt')
write.table(results_table, file = "DEgenes_Liver.txt")
SummaryKallisto_table<- kallisto_table(so, use_filtered = FALSE, normalized = TRUE, include_covariates = TRUE)
write.table(SummaryKallisto_table, file = "KallistoSummary_Liver.txt")

